@@ -1,5 +1,6 @@
 import logging
 import threading
+import time
 
 from kikyo import Kikyo, DataHub
 
@@ -15,6 +16,7 @@ class KikyoConsumer(BaseConsumer):
         self.is_running = True
         self.consumer = None
         self._consumer_lock = threading.Lock()
+        self._delay = self.worker.settings.get('consumer_delay')
 
     @property
     def kikyo(self) -> Kikyo:
@@ -41,6 +43,11 @@ class KikyoConsumer(BaseConsumer):
                         break
                     msg = self.consumer.receive()
 
+                if self._delay is not None:
+                    t = msg.publish_time.timestamp() + self._delay - time.time()
+                    if t > 0.1:
+                        time.sleep(t)
+
                 data = msg.value
                 self.worker.process(data)
                 if not self.worker.debug:
