@@ -35,3 +35,14 @@ def predict_themes(content: str) -> list:
     )
     resp.raise_for_status()
     return resp.json()['result']
+
+
+@retry_rest_api
+def content_ner(content: str) -> dict:
+    resp = requests.post(
+        f'{YURI_API_HOST}/content-ner/api/ner',
+        json={'text': content},
+        timeout=20,
+    )
+    resp.raise_for_status()
+    return resp.json()['data']
