@@ -27,7 +27,7 @@ def retry_rest_api(n: int = None, wait: int = 3):
                     k = 0
                 except HTTPError as e:
                     last_error = e
-                    if e.response and e.response.status_code not in RETRY_HTTP_CODES:
+                    if e.response is not None and e.response.status_code not in RETRY_HTTP_CODES:
                         k = 0
                 k -= 1
                 if k >= 0 and wait > 0:
